@@ -8,7 +8,7 @@ from typing import Dict, Any, final
 from tornado.web import RequestHandler, Application
 from pyppeteer.launcher import Launcher, DEFAULT_ARGS
 from pyppeteer.page import Page
-from arts.cooltypes import json_chinese, get_chrome_path, get_free_port
+from arts.vtype import json_chinese, get_chrome_path, get_free_port
 
 
 # 使不会提示'缺少 Google API 密钥, 因此 Chromium 的部分功能将不可使用。'
